@@ -3,8 +3,9 @@
 use crate::block::commit_sig::CommitSig;
 use crate::block::{Height, Id, Round};
 use crate::error::Error;
+use crate::prelude::*;
+use core::convert::{TryFrom, TryInto};
 use serde::{Deserialize, Serialize};
-use std::convert::{TryFrom, TryInto};
 use tendermint_proto::types::Commit as RawCommit;
 
 /// Commit contains the justification (ie. a set of signatures) that a block was committed by a set
