@@ -1,9 +1,10 @@
 //! Block headers
 
 use crate::merkle::simple_hash_from_byte_vectors;
+use crate::prelude::*;
 use crate::{account, block, chain, AppHash, Error, Hash, Time};
+use core::convert::{TryFrom, TryInto};
 use serde::{Deserialize, Serialize};
-use std::convert::{TryFrom, TryInto};
 use tendermint_proto::types::Header as RawHeader;
 use tendermint_proto::version::Consensus as RawConsensusVersion;
 use tendermint_proto::Protobuf;
@@ -112,7 +113,10 @@ impl TryFrom<RawHeader> for Header {
             version: value.version.ok_or_else(Error::missing_version)?.into(),
             chain_id: value.chain_id.try_into()?,
             height,
-            time: value.time.ok_or_else(Error::missing_timestamp)?.into(),
+            time: value
+                .time
+                .ok_or_else(Error::missing_timestamp)?
+                .try_into()?,
             last_block_id,
             last_commit_hash,
             data_hash: if value.data_hash.is_empty() {
