@@ -2,8 +2,8 @@
 //! It is what the rpc endpoint /commit returns and hence can be used by a
 //! light client.
 use crate::{block, Error};
+use core::convert::{TryFrom, TryInto};
 use serde::{Deserialize, Serialize};
-use std::convert::{TryFrom, TryInto};
 use tendermint_proto::{types::SignedHeader as RawSignedHeader, Protobuf};
 
 /// Signed block headers
