@@ -4,6 +4,7 @@
 //! blockchain networks, including chain information types, secret connections,
 //! and remote procedure calls (JSON-RPC).
 
+#![no_std]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![deny(
     warnings,
@@ -14,12 +15,15 @@
 )]
 #![forbid(unsafe_code)]
 #![doc(
-    html_root_url = "https://docs.rs/tendermint/0.22.0",
+    html_root_url = "https://docs.rs/tendermint/0.23.0",
     html_logo_url = "https://raw.githubusercontent.com/informalsystems/tendermint-rs/master/img/logo-tendermint-rs_3961x4001.png"
 )]
 
 extern crate alloc;
 
+#[cfg(test)]
+extern crate std;
+
 #[macro_use]
 pub mod error;
 
@@ -28,15 +32,14 @@ pub mod account;
 pub mod block;
 pub mod chain;
 pub mod channel;
-pub mod config;
 pub mod consensus;
 pub mod evidence;
 pub mod genesis;
 pub mod hash;
 pub mod merkle;
 mod moniker;
-pub mod net;
 pub mod node;
+mod prelude;
 pub mod private_key;
 pub mod proposal;
 pub mod public_key;
