@@ -1,6 +1,6 @@
 //! Tendermint node IDs
 
-use std::{
+use core::{
     convert::TryFrom,
     fmt::{self, Debug, Display},
     str::FromStr,
@@ -11,6 +11,7 @@ use sha2::{Digest, Sha256};
 use subtle::{self, ConstantTimeEq};
 use subtle_encoding::hex;
 
+use crate::prelude::*;
 use crate::{
     error::Error,
     public_key::{Ed25519, PublicKey},
