@@ -1,5 +1,5 @@
+use core::fmt::Debug;
 use serde::{de::DeserializeOwned, Serialize};
-use std::fmt::Debug;
 
 /// Test that a struct `T` can be:
 ///
