@@ -1,12 +1,14 @@
 //! Timestamps used by Tendermint blockchains
 
-use chrono::{DateTime, Utc};
+use chrono::{DateTime, LocalResult, TimeZone, Utc};
 use serde::{Deserialize, Serialize};
 
-use std::fmt;
-use std::ops::{Add, Sub};
-use std::str::FromStr;
-use std::time::{Duration, SystemTime, UNIX_EPOCH};
+use crate::prelude::*;
+use core::convert::{TryFrom, TryInto};
+use core::fmt;
+use core::ops::{Add, Sub};
+use core::str::FromStr;
+use core::time::Duration;
 use tendermint_proto::google::protobuf::Timestamp;
 use tendermint_proto::serializers::timestamp;
 use tendermint_proto::Protobuf;
@@ -16,54 +18,55 @@ use crate::error::Error;
 /// Tendermint timestamps
 /// <https://github.com/tendermint/spec/blob/d46cd7f573a2c6a2399fcab2cde981330aa63f37/spec/core/data_structures.md#time>
 #[derive(Copy, Clone, Debug, Eq, PartialEq, PartialOrd, Ord, Serialize, Deserialize)]
-#[serde(try_from = "Timestamp", into = "Timestamp")]
-pub struct Time(DateTime<Utc>);
+#[serde(try_from = "Timestamp")]
+pub struct Time(pub DateTime<Utc>);
 
 impl Protobuf<Timestamp> for Time {}
 
-impl From<Timestamp> for Time {
-    fn from(value: Timestamp) -> Self {
-        // prost_types::Timestamp has a SystemTime converter but
-        // tendermint_proto::Timestamp can be JSON-encoded
-        let prost_value = prost_types::Timestamp {
-            seconds: value.seconds,
-            nanos: value.nanos,
-        };
+impl TryFrom<Timestamp> for Time {
+    type Error = Error;
 
-        SystemTime::from(prost_value).into()
+    fn try_from(value: Timestamp) -> Result<Self, Error> {
+        let nanos = value.nanos.try_into().map_err(Error::timestamp_overflow)?;
+        Time::from_unix_timestamp(value.seconds, nanos)
     }
 }
 
 impl From<Time> for Timestamp {
     fn from(value: Time) -> Self {
-        // prost_types::Timestamp has a SystemTime converter but
-        // tendermint_proto::Timestamp can be JSON-encoded
-        let prost_value = prost_types::Timestamp::from(SystemTime::from(value));
+        // Subsecond nanoseconds returned by timestamp_subsec_nanos should have a value
+        // between 0 and 999,999,999. So that shouldn't cause an overflow when converting
+        // from u32 to i32. However in case there is an unexpected conversion error,
+        // we default to 0, and hopefully does not cause any undefined behavior.
+        let nanos = value.0.timestamp_subsec_nanos().try_into().unwrap_or(0);
+
         Timestamp {
-            seconds: prost_value.seconds,
-            nanos: prost_value.nanos,
+            seconds: value.0.timestamp(),
+            nanos,
         }
     }
 }
 
 impl Time {
-    /// Get [`Time`] value representing the current wall clock time
-    pub fn now() -> Self {
-        Time(Utc::now())
+    /// Get the unix epoch ("1970-01-01 00:00:00 UTC") as a [`Time`]
+    pub fn unix_epoch() -> Self {
+        Time(Utc.timestamp(0, 0))
     }
 
-    /// Get the [`UNIX_EPOCH`] time ("1970-01-01 00:00:00 UTC") as a [`Time`]
-    pub fn unix_epoch() -> Self {
-        UNIX_EPOCH.into()
+    pub fn from_unix_timestamp(secs: i64, nanos: u32) -> Result<Self, Error> {
+        match Utc.timestamp_opt(secs, nanos) {
+            LocalResult::Single(time) => Ok(Time(time)),
+            _ => Err(Error::timestamp_conversion()),
+        }
     }
 
     /// Calculate the amount of time which has passed since another [`Time`]
-    /// as a [`std::time::Duration`]
+    /// as a [`core::time::Duration`]
     pub fn duration_since(&self, other: Time) -> Result<Duration, Error> {
         self.0
             .signed_duration_since(other.0)
             .to_std()
-            .map_err(Error::out_of_range)
+            .map_err(|_| Error::duration_out_of_range())
     }
 
     /// Parse [`Time`] from an RFC 3339 date
@@ -106,33 +109,35 @@ impl From<Time> for DateTime<Utc> {
     }
 }
 
-impl From<SystemTime> for Time {
-    fn from(t: SystemTime) -> Time {
-        Time(t.into())
-    }
-}
-
-impl From<Time> for SystemTime {
-    fn from(t: Time) -> SystemTime {
-        t.0.into()
-    }
-}
-
 impl Add<Duration> for Time {
-    type Output = Self;
+    type Output = Result<Self, Error>;
 
     fn add(self, rhs: Duration) -> Self::Output {
-        let st: SystemTime = self.into();
-        (st + rhs).into()
+        let duration =
+            chrono::Duration::from_std(rhs).map_err(|_| Error::duration_out_of_range())?;
+
+        let res = self
+            .0
+            .checked_add_signed(duration)
+            .ok_or_else(Error::duration_out_of_range)?;
+
+        Ok(Time(res))
     }
 }
 
 impl Sub<Duration> for Time {
-    type Output = Self;
+    type Output = Result<Self, Error>;
 
     fn sub(self, rhs: Duration) -> Self::Output {
-        let st: SystemTime = self.into();
-        (st - rhs).into()
+        let duration =
+            chrono::Duration::from_std(rhs).map_err(|_| Error::duration_out_of_range())?;
+
+        let res = self
+            .0
+            .checked_sub_signed(duration)
+            .ok_or_else(Error::duration_out_of_range)?;
+
+        Ok(Time(res))
     }
 }
 
