@@ -1,8 +1,9 @@
 use crate::chain::Id as ChainId;
 use crate::error::Error;
+use crate::prelude::*;
 use crate::{block, Time};
+use core::convert::{TryFrom, TryInto};
 use serde::{Deserialize, Serialize};
-use std::convert::{TryFrom, TryInto};
 use tendermint_proto::types::CanonicalVote as RawCanonicalVote;
 use tendermint_proto::Protobuf;
 
@@ -49,7 +50,7 @@ impl TryFrom<RawCanonicalVote> for CanonicalVote {
             height: value.height.try_into()?,
             round: (value.round as i32).try_into()?,
             block_id: block_id.map(|b| b.try_into()).transpose()?,
-            timestamp: value.timestamp.map(|t| t.into()),
+            timestamp: value.timestamp.map(|t| t.try_into()).transpose()?,
             chain_id: ChainId::try_from(value.chain_id)?,
         })
     }
@@ -87,9 +88,10 @@ impl CanonicalVote {
 
 #[cfg(test)]
 mod tests {
+    use crate::prelude::*;
     use crate::vote::canonical_vote::CanonicalVote;
     use crate::vote::Type;
-    use std::convert::TryFrom;
+    use core::convert::TryFrom;
     use tendermint_proto::google::protobuf::Timestamp;
     use tendermint_proto::types::CanonicalBlockId as RawCanonicalBlockId;
     use tendermint_proto::types::CanonicalPartSetHeader as RawCanonicalPartSetHeader;
